# Lace utils

Misc utilities for lace and shared libraries.

- `stats`: computes statistics from data
- `numbers`: computes special numbers
- `random`: random generation utilities
- `misc`: everything else
